==> ToolChain_STM32_1.0.50.tar.bz: ToolChain_STM32_1.0.50/ToolChain/install_04_BasicExtensions.sh <==
#!/bin/bash
#            ToolChain_STM32
#
#  Install script for basic extensions.
#
#  Script written by Gregor Rebel 2012
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# openSuSE 12.1 x86
# XUbuntu 11.10 x64
# Restaurant, Tanzen, Kneipe, Kino, Bowling

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="000_basic_extensions"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------
  
  if [ ! -e OK.Documentation ]; then #{
    Dir=`pwd`

    # nothing to document (yet)

    if [ "$Error" == "" ]; then
      #echo "Documentation complete: $INSTALLPATH."
      touch OK.Documentation
    fi
  fi #}
  if [ ! -e OK.Install ]; then #{
    
    if [ ! -e OK.Packages ]; then #{
      # nothing to install (yet)
      Arch=`uname -i`
      if [ "$Arch" == "x86_64" ]; then
        installPackage "ia32-libs"
      fi
      touch OK.Install
      touch OK.Packages
    fi #}
  fi #}
  if [ -e OK.Install ]; then #{
    
    Name="${INSTALLPATH}_basic_setup"
    createExtensionMakefileHead ${Name} #{         create makefile for extension
    File="../extensions/makefile.${Name}" 
    cat <<END_OF_MAKEFILE >>$MakeFile 

COMPILE_OPTS += -DEXTENSION_${Name}=1

# basic software interface of TheToolChain (ttc_XXX() functions)
INCLUDE_DIRS += -I common/
INCLUDE_DIRS += -I examples/

vpath %.c common/ examples/

# add some basic object files which are always available
MAIN_OBJS +=  ttc_extensions.o ttc_basic.o

END_OF_MAKEFILE
    createExtensionMakefileTail ${Name} #}
    File="../extensions/activate.${Name}.sh"
    createActivateScriptHead $File $0 "Basic toolchain settings required by all architectures and boards."
    if [ "$Delete" != "" ]; then
      echo "rm 2>/dev/null \$Dir_ExtensionsActive/${INSTALLPATH}" >>$File
    fi
    ../scripts/printBaseExtensions.sh >>$File
    cat <<END_OF_ACTTIVATE >>$File

createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET

END_OF_ACTTIVATE
    createActivateScriptTail $File $Name

    Name="${INSTALLPATH}_optimize_1_debug"
    createExtensionMakefileHead ${Name}
    cat <<END_OF_MAKEFILE >>$MakeFile #{
  
  DEBUG=1
  OPTIMIZE=-O0 -g3

END_OF_MAKEFILE
#}
    createExtensionMakefileTail ${Name}
    createActivateScript "../extensions/activate.${Name}.sh" $Name "makefile.${INSTALLPATH}_optimize_1_*" "$0" "compile option: do not optimize at all (best visibility during debugging)"

    Name="${INSTALLPATH}_optimize_1_smallest"
    createExtensionMakefileHead ${Name}
    cat <<END_OF_MAKEFILE >>$MakeFile #{
    
OPTIMIZE=-Os 

END_OF_MAKEFILE
#}
    createExtensionMakefileTail ${Name}
    createActivateScript "../extensions/activate.${Name}.sh" $Name "makefile.${INSTALLPATH}_optimize_1_*" "$0" "compiler option: create small code (can degrade execution speed)"

    Name="${INSTALLPATH}_optimize_1_fastest"
    createExtensionMakefileHead ${Name}
    cat <<END_OF_MAKEFILE >>$MakeFile #{

  OPTIMIZE=-O9

END_OF_MAKEFILE
#}
    createExtensionMakefileTail ${Name}
    createActivateScript "../extensions/activate.${Name}.sh" $Name "makefile.${INSTALLPATH}_optimize_1_*" "$0" "compiler option: create fast code (can increase code- and memory-usage)"
    
    Name="${INSTALLPATH}_optimize_2_inline"
    createExtensionMakefileHead ${Name} #{
    cat <<END_OF_MAKEFILE >>$MakeFile 

COMPILE_OPTS += -finline -finline-functions-called-once

END_OF_MAKEFILE
    createExtensionMakefileTail ${Name} #}
    createActivateScript "../extensions/activate.${Name}.sh" $Name "" "$0" "compiler option: try to inline as many functions as possible (can increase code- and memory-usage)"

    Name="${INSTALLPATH}_enable_no_argument_checks"
    createExtensionMakefileHead ${Name} #{
    cat <<END_OF_MAKEFILE >>$MakeFile 

COMPILE_OPTS += -DTTC_NO_ARGUMENT_CHECKS

END_OF_MAKEFILE
    createExtensionMakefileTail ${Name} #}
    createActivateScript "../extensions/activate.${Name}.sh" $Name "" "$0" "Disables argument checking in ttc_XXX() functions. Use with caution!"

    echo "Installed successfully: $INSTALLPATH"
  fi #}
  cd ..
  rmdir 2>/dev/null $INSTALLPATH  # removes only empty install dir
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0

==> ToolChain_STM32_1.0.51.tar.bz: ToolChain_STM32_1.0.51/ToolChain/install_04_BasicExtensions.sh <==
#!/bin/bash
#            ToolChain_STM32
#
#  Install script for basic extensions.
#
#  Script written by Gregor Rebel 2012
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# openSuSE 12.1 x86
# XUbuntu 11.10 x64
# Restaurant, Tanzen, Kneipe, Kino, Bowling

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="000_basic_extensions"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------
  
  if [ ! -e OK.Documentation ]; then #{
    Dir=`pwd`

    # nothing to document (yet)

    if [ "$Error" == "" ]; then
      #echo "Documentation complete: $INSTALLPATH."
      touch OK.Documentation
    fi
  fi #}
  if [ ! -e OK.Install ]; then #{
    
    if [ ! -e OK.Packages ]; then #{
      # nothing to install (yet)
      Arch=`uname -i`
      if [ "$Arch" == "x86_64" ]; then
        installPackage "ia32-libs"
      fi
      touch OK.Install
      touch OK.Packages
    fi #}
  fi #}
  if [ -e OK.Install ]; then #{
    
    Name="${INSTALLPATH}_basic_setup"
    createExtensionMakefileHead ${Name} #{         create makefile for extension
    File="../extensions/makefile.${Name}" 
    cat <<END_OF_MAKEFILE >>$MakeFile 

COMPILE_OPTS += -DEXTENSION_${Name}=1

# basic software interface of TheToolChain (ttc_XXX() functions)
INCLUDE_DIRS += -I common/
INCLUDE_DIRS += -I common/scheduler/
INCLUDE_DIRS += -I examples/

vpath %.c common/ common/scheduler/ examples/

# add some basic object files which are always available
MAIN_OBJS += ttc_extensions.o ttc_basic.o

END_OF_MAKEFILE
    createExtensionMakefileTail ${Name} #}
    File="../extensions/activate.${Name}.sh"
    createActivateScriptHead $File $0 "Basic toolchain settings required by all architectures and boards."
    if [ "$Delete" != "" ]; then
      echo "rm 2>/dev/null \$Dir_ExtensionsActive/${INSTALLPATH}" >>$File
    fi
    ../scripts/printBaseExtensions.sh >>$File
    cat <<END_OF_ACTTIVATE >>$File #{

createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET

END_OF_ACTTIVATE
#}
    createActivateScriptTail $File $Name

    Name="${INSTALLPATH}_optimize_1_debug"
    createExtensionMakefileHead ${Name}
    cat <<END_OF_MAKEFILE >>$MakeFile #{
  
  DEBUG=1
  OPTIMIZE=-O0 -g3

END_OF_MAKEFILE
#}
    createExtensionMakefileTail ${Name}
    createActivateScript "../extensions/activate.${Name}.sh" $Name "makefile.${INSTALLPATH}_optimize_1_*" "$0" "compile option: do not optimize at all (best visibility during debugging)"

    Name="${INSTALLPATH}_optimize_1_smallest"
    createExtensionMakefileHead ${Name}
    cat <<END_OF_MAKEFILE >>$MakeFile #{
    
OPTIMIZE=-Os 

END_OF_MAKEFILE
#}
    createExtensionMakefileTail ${Name}
    createActivateScript "../extensions/activate.${Name}.sh" $Name "makefile.${INSTALLPATH}_optimize_1_*" "$0" "compiler option: create small code (can degrade execution speed)"

    Name="${INSTALLPATH}_optimize_1_fastest"
    createExtensionMakefileHead ${Name}
    cat <<END_OF_MAKEFILE >>$MakeFile #{

  OPTIMIZE=-O9

END_OF_MAKEFILE
#}
    createExtensionMakefileTail ${Name}
    createActivateScript "../extensions/activate.${Name}.sh" $Name "makefile.${INSTALLPATH}_optimize_1_*" "$0" "compiler option: create fast code (can increase code- and memory-usage)"
    
    Name="${INSTALLPATH}_optimize_2_inline"
    createExtensionMakefileHead ${Name} #{
    cat <<END_OF_MAKEFILE >>$MakeFile 

COMPILE_OPTS += -finline -finline-functions-called-once

END_OF_MAKEFILE
    createExtensionMakefileTail ${Name} #}
    createActivateScript "../extensions/activate.${Name}.sh" $Name "" "$0" "compiler option: try to inline as many functions as possible (can increase code- and memory-usage)"

    Name="${INSTALLPATH}_enable_no_argument_checks"
    createExtensionMakefileHead ${Name} #{
    cat <<END_OF_MAKEFILE >>$MakeFile 

COMPILE_OPTS += -DTTC_NO_ARGUMENT_CHECKS

END_OF_MAKEFILE
    createExtensionMakefileTail ${Name} #}
    createActivateScript "../extensions/activate.${Name}.sh" $Name "" "$0" "Disables argument checking in ttc_XXX() functions. Use with caution!"

    echo "Installed successfully: $INSTALLPATH"
  fi #}
  cd ..
  rmdir 2>/dev/null $INSTALLPATH  # removes only empty install dir
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0
